Changelog
---------


0.1.0
~~~~~

* Allow to set template base path via class attribute


0.0.3
~~~~~

* Improve default templates directory search


0.0.2
~~~~~

* Add PdfRenderer


0.0.1
~~~~~

* Initial release
